function [E3,N3,El,Nl,U]=TerraceM_okada(Sf,Bx,param)
%fault=2; dip=80; slip=10;

%parameters
Dip=param.Dip;
Slip=param.Slip;
Updip=param.Updip;
Downdip=param.Downdip;
Rake=param.Rake;
d=param.d;
pplot=param.pplot;

%check the box
E1=round(min(Bx.X)/d)*d;
E2=round(max(Bx.X)/d)*d;
N1=round(min(Bx.Y)/d)*d;
N2=round(max(Bx.Y)/d)*d;

[E3,N3] = meshgrid(E1-1.5*(E2-E1):d:E2+1.5*(E2-E1),N1-1.5*(N2-N1):d:N2+1.5*(N2-N1));
clear U
U=zeros(numel(E3(:,1)),numel(E3(1,:)));
Nl=zeros(numel(E3(:,1)),numel(E3(1,:)));
El=zeros(numel(E3(:,1)),numel(E3(1,:)));


%loop faults in shapefile
for fault=1:numel(Sf) 

%arrange parameters
dip=Dip(fault);
slip=Slip(fault);
udepth=Updip(fault);
ddepth=Downdip(fault);
rake=Rake(fault);
    
%%%%%%%%%%%%%%%
% Extract fault coordinates
fx=Sf(fault).X; fx(end)=[];
fy=Sf(fault).Y; fy(end)=[];

% Fault length
L=hypot(fx(1,end)-fx(1,1),fy(1,end)-fy(1,1));
% Fault Strike
strike=atand((fx(1,end)-fx(1,1))/(fy(1,end)-fy(1,1)));
% Fault trace center
fcx=(fx(1)+fx(end))/2; 
fcy=(fy(1)+fy(end))/2;
% Round coordinates to nearest cell size integer
fcx=round(fcx/d)*d;
fcy=round(fcy/d)*d;
% Mesh parameters
%d=100; %grid size in m

go=(E2-E1);%/2
%go2=(N2-N1)/4;
%go=min([go1, go2])

%go=4e4; %half domain size in m

%local coordinates
[E,N] = meshgrid(-go:d:go,-go:d:go);
% define OKADA inputs
%udepth=0; %updip limit in m
%ddepth=12e3; %downdip limit
W=(ddepth-udepth)/sind(dip); %Fault width
cdepth=((ddepth-udepth)/2)+udepth; %Centroid depth
open=0; 
%rake=70; 
% Run okada function
[uN,uE,uZ] = okada85(E,N,cdepth,strike,dip,L,W,rake,slip,open);

uZ=uZ;%adjust center
%distance from centroid to fault trace center
dd=cosd(dip)*W/2; %W/2
foE=dd*sind(90+strike);
foN=dd*cosd(90+strike);
% Round coordinates to nearest cell size integer
foE=round(foE/d)*d;
foN=round(foN/d)*d;

% mesh in UTM
[Eutm,Nutm] = meshgrid(fcx-go+foE:d:fcx+go+foE,fcy-go+foN:d:fcy+go+foN);

%if pplot==1
%figure(3), clf, hold on
%pcolor(Eutm,Nutm,uZ)
%colormap(demcmap(uZ))
%shading flat
%plot([Sf.X],[Sf.Y],'-k')
%colorbar
%plot(fx,fy,'-k','linewidth',2)
%plot(fcx,fcy,'ok')
%title('Vertical displacement ')
%axis equal tight, box on
%xlabel('East (m)'); ylabel('North (m)');
%rect = [2,4,16,22]; set(gcf,'PaperUnits','centimeters'); set(gcf, 'PaperType','A4'); set(gcf,'paperposition',rect);
%fout = sprintf('fault_%u_okadamap.pdf',fault); saveas(gcf,fout,'pdf');
%end

EXUTM=round(Eutm(1,1)/d)*d;
NYUTM=round(Nutm(1,1)/d)*d; 

%magic
    [~,iy]=find(round(E3(1,:)/d)*d == EXUTM);
    [ix,~]=find(round(N3(:,1)/d)*d==NYUTM);
    % paste results on one fault into large mesh
    [nx,ny]=size(uZ);
    U(ix:ix+nx-1,iy:iy+ny-1)=U(ix:ix+nx-1,iy:iy+ny-1)+uZ(:,:); 
    
    Nl(ix:ix+nx-1,iy:iy+ny-1)=Nl(ix:ix+nx-1,iy:iy+ny-1)+uN(:,:); 
    
    El(ix:ix+nx-1,iy:iy+ny-1)=El(ix:ix+nx-1,iy:iy+ny-1)+uE(:,:); 

end


if pplot==1
figure(3), clf, hold on, box on
pcolor(E3,N3,U)
colormap(demcmap(U))
shading flat
plot([Sf.X],[Sf.Y],'-k')
c=colorbar;
c.Label.String = 'Vertical displacement (m)';
plot(fx,fy,'-k','linewidth',2)
plot(fcx,fcy,'ok')
axis equal tight, box on
xlabel('East (m)'); ylabel('North (m)');
%rect = [2,4,16,22]; set(gcf,'PaperUnits','centimeters'); set(gcf, 'PaperType','A4'); set(gcf,'paperposition',rect);
%fout = sprintf('fault_%u_okadamap.pdf',fault); saveas(gcf,fout,'pdf');
end







