%%%%%%%%%%%%%%%%%%%%%%%% Anderson function %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [LEM,varargout]=TerraceM_anderson(sl,param)

if length(fieldnames(param))>13
   h2 = param.h1;
   h3 = param.h2;
   snap = param.snap;
   cumula=param.cumula;

   inputset=1;    
else
    inputset=0;
    if param.video==1
    fig=figure('units','normalized','Visible','off');
    h2 = subplot(3,1,1:2); box on
    h3 = subplot(3,1,3); box on
    cumula=0;
    end
end   

%parameters
tmax1=param.tmax;
tmin1=param.tmin;
dt=param.dt;
dx=param.dx;
sill=param.sill;
slope_shelf=param.slope_shelf;
uplift_rate=param.uplift_rate;
edot0=param.initial_erosion;
diff1=param.cliff_diffusion;
wave=param.wave_height;
vxx=param.vxx;
smth=param.smth;
video=param.video;

%
TEXT='';
sl=sl.ans;
sl(sl(:,2)>sill,2)=sill; %sill effect

% Can change the following variables: uplift rate (uprate) cliff erosion rate (edot0); and shelf slope (slope2)
if numel(uplift_rate)==1
mode=1;
uprate = uplift_rate/1000; % uplift rate in m/yr
else
mode=2;
%load('urate.mat');
uprate=max(uplift_rate)/1000;
uprate666=flipud(uplift_rate./1000);
end
%uprate = max(uprate1)/1000;

slope2 = tand(slope_shelf); 

tmax=tmax1*1000; %minimum  age 69000 / 83000
tmin=tmin1*1000; %maximum age 13000 /0

%%%%%%%%%%
M=sl(sl(:,1)<=tmax,:); 
M2=M(M(:,1)>=tmin,:); %adjust range for analysis in time window

%remove repeated
J=find(diff(M2(:,1))==0);
M2(J,:)=[];

xi = tmin:dt:tmax; %time steps
sea1=interp1(M2(:,1),M2(:,2),xi,'nearest')';

%sea2=-flipud(sea1);
sea=smooth(-flipud(sea1)',smth);
time=xi;

%define Y axis range 
seamean=mean(sea);
seaamp=max(sea)-min(sea);

ttmax=max(time); 
ttmin=min(time);

%jmax=((tmax)/dt)+1;%only for runs to present
jmax=((tmax-tmin)/dt);


%request additional extend to x axis when plot outside video zone
%vx=500+vxx;
%vx=(tmax*uprate*(1-slope2))+vxx;
% this is the topographic diffusivity in m^2/year
kappa0 = diff1;%0.015;

% this is the depth to which one will feel waves significantly 
zstar=wave; %Wave height
wavedepth=3*zstar;
dissscale=dx*wavedepth;

slope = slope2; 
%zmin=(seamean-seaamp)-(tmax*uprate)-(vx/3) ;%-40
%zmax=(seamean+seaamp)+vx; %+200 %xmax=5000;
zmin=(seamean-seaamp)-(tmax*uprate)-seaamp-vxx ;%-40
zmax=(seamean+seaamp)+(tmax*uprate*1)+vxx;
xmax=(zmax-zmin)/slope;
x=1:dx:xmax; %x topography
imax=length(x);
z0=zmin+(slope*x);%y topography
z=z0;%y topography

%nprint=200; %number of snapshots
if inputset==1
nprint=snap; %number of snapshots
else
    if video==1
    nprint=65;    
    else
    nprint=1;
    end
end
        
jprint=floor(jmax/nprint); 
numprint = 0;

xplot = x/1000; 
xmaxplot = max(xplot);

if video==1
axes (h3);%%%%%%%%%%%%%%%%%%%%
tplot = (time-tmax)/1000;
plot(tplot,sea,'b');
xlabel('Time (kyr)','fontsize',18,'fontname','times') ;
ylabel('Sealevel (m)','fontsize',18,'fontname','times'); 
axis([-ttmax/1000 0 -130 20]) 
set(gca,'fontsize',14,'fontname','times')
M1 = moviein(nprint,h3);

axes(h2)%%%%%%%%%%%%%%%%%%%%%
plot(xplot,z,'k');
axis([0 xmaxplot min(z0) max(z0+(uprate*tmax))]); 
xlabel('Horizontal Distance (km)');
ylabel('Elevation (m)')
M2 = moviein(nprint,h2);

end

zsave=[x;z];
conto=1;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ********** start the time clock ************* 
for j=1:jmax
% the uplift pattern, here taken to be uniform in x 

if mode==1
uplift=uprate*dt*ones(1,length(x));    
else
uplift=uprate666(j)*dt*ones(1,length(x));
end

surface=sea(j)*ones(1,length(x));
k=find(z>=surface);
z=z+uplift;
% find the intersection of the sea surface and the topography 
try

%k=find(z>surface);%> 


xsea1(j)=x(k(1));
tsea1(j)=(j)*dt;%time at time step
%k2=find(z>=surface);
%zsea1(j)=z(k2(1));%z sea position at time step
catch
msgbox('Caution , low accuracy resut')
TEXT('Caution , low accuracy resut');
return
end
% dependence of the cliff erosion rate on the width of the shelf, now ignored
%Selected area for depth decay=depth of wave erosion
ggd=find(((sea(j)-wavedepth)<z)&(sea(j)>z)); %submarine part affected by waves

%boundaries of platform / experimental
length2_max=max(x(1,ggd));
lenght2_min=min(x(1,ggd));
length_total=length2_max-lenght2_min; %width of platform
%reduction of erosion rate proportional to platform width 
%edot3=(length_total/max(x)/2); %weighted platform lenght 
edot1=edot0;
% the most important segments being closest to the instantaneous 
% coastline
gg=find(((sea(j)-wavedepth)<z)&(sea(j)>z)); 
%dissrate=(1-exp(-(sea(j)-z(1,gg))/wavedepth))*dx;

dissrate=exp((sea(j)-z(1,gg))/wavedepth)*dx;
dissipate=sum(dissrate);
edot=edot1*(dissscale/dissipate);
%edot=edot0;
ero(j)=edot;
ksea=k(1)+ceil(edot*dt/dx); %round reeplaced by ceil
try
  
shelf=z(k(1))+(slope2*(x-x(k(1))));
surface(1:(k(1)-1))=9999*ones(size(1:k(1)-1)); 
surface(ksea+1:imax)=9999*ones(size(ksea+1:imax)); 
z=min(z,surface);
xsea(j)=x(ksea+1); %-1

% now take into account erosion in this reach of
% nearshore area where water depths are < "wavedepth" 
ggnew=find(((sea(j)-wavedepth)<z)&(sea(j)>z)); 
nearshore=wavedepth/(x(max(ggnew))-x(ggnew(1))); 
znew=z(1,ggnew(1))+(nearshore*(x(1,ggnew)-x(1,ggnew(1)))); 
z(1,ggnew)=min(z(1,ggnew),znew);

%now diffuse the terrestrial portion of the space 
kappa=zeros(1,length(x));
kkk=find(x>xsea(j)); 
kappa1=kappa0*ones(1,length(kkk)); 
kappa(kkk(1):imax)=kappa1;

catch
msgbox('Error: increase the value Vx to extend the plot display') 
TEXT=('Info:  Error¡¡¡¡ Increase the value Vx to extend the plot display'); 
return
end 

dzdt = 4 * kappa .* ((del2(z)./(dx*dx))); 
z=z+(dzdt*dt);

%snapshot of this 
p=rem(j,jprint);

if p == 0 && video==1   %if solo snapshots
numprint = numprint+1;
axes(h3);

    %progressive urate evolution
    if numel(uplift_rate)~=1
    yyaxis left
    end

tplot = ((time-tmax))/1000;
plot(tplot,sea,'b')

xlabel('Time (ka)') 
ylabel('Sealevel (m)') 
axis([-ttmax/1000 0 -130 20])
hold on
plot(tplot,sea,'-b');
tnow = (time(j)-tmax)/1000; 
plot(tnow,sea(j),'rd','linewidth',3.0) 
set(gca,'fontsize',10,'fontname','times')
hold off
plt1 = gca;
plt1.YColor=[0 0 0];


M1(:,numprint) = getframe(h3); % if you dont want movies comment this out

xp1 = xplot;
xpatch = [0 xp1 xp1(imax:-1:1)];
zp1 = z;
zp2 = min(z0)*ones(1,length(x)); 
zpatch = [min(z0) zp1 zp2(imax:-1:1)];

%%%%%%%%%%%%%%%%%%%%%% variable uplift rate
if numel(uplift_rate)~=1

axis([-ttmax/1000 0 -130 20])

yyaxis right

plot(-xi/1e3,flipud(uprate666)*1e3,'-','color',[0 0.6 0])
hold on
plot(-xi/1e3,flipud(uprate666)*1e3,'-','color',[0 0.6 0])
tnow2 = (time(j)-tmax)/1e3; 
plot(tnow2,uprate666(j)*1e3,'gd','linewidth',3.0) 
hold off
xlabel('Time (ka)'), ylabel('Uplift rate (m/ka)')

plt = gca;
plt.YColor=[0 0.6 0];
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

axes(h2);
%cla %--> make permanently deleted
hold on
if cumula==0
cla(gca) %cummulative desativated
end

plot(xpatch,zpatch,'k'); %patch(xpatch,zpatch,'k');
axis([0 xmaxplot min(z0) max(z0+(uprate*tmax))]); 
xlabel('Horizontal Distance (km)') 
ylabel('Elevation (m)') 
set(gca,'fontsize',10,'fontname','times')
hold on
seanow = sea(j)*ones(1,ksea);
xnowplot = xplot(1:ksea); 

if cumula==0
slpl=plot(xnowplot,seanow,'b','linewidth',3.0);
end

pause(0.0000001)

hold off


zsave=[zsave;z];
edot ;
abs(time(j)-tmax);
M2(:,numprint) = getframe(h2); % if you dont want movies comment this out

%MM(conto)=getframe;


%movie(M2)

else

    tplot = (time-tmax)/1000;
    tnow = (time(j)-tmax)/1000; 
    seanow = sea(j)*ones(1,ksea);
    xnowplot = xplot(1:ksea);
end
conto=conto+1;
%writevideo(writerObj,MM);

end


x_mod=x;
z_mod=z;
%%%%%%%%%%%%%%%%%%%%%%%%NEW&%%%%%%%%%%%%%%%%%%%%%%%
xsea1(end)=xsea1(end)+dx;%rectify xsea1 shoreline angle
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

idxs = arrayfun(@(x)find(x_mod==x,1),xsea1);
ysea1=z_mod(idxs); %maybe wrong


%LEM.xsea=xsea; 
LEM.xsea1=xsea1;
LEM.ysea1=ysea1;
LEM.x_mod=x;
LEM.z_mod=z;
LEM.sea_rec=max(tsea1)-tsea1;%tsea1
LEM.ero_mod=ero;


varargout{1}=TEXT;
%close(writerObj);
