
%%%%%%%%%%%%%%%%%%%%%%%% Fit profile function %%%%%%%%%%%%%%

function [Result,MOD]=TerraceM_rms_fit(LEM,LEM2,prof,sw,sh,age,ratio,cycle,up,down,mode,savepdf)


tsea1=LEM.sea_rec;%tsea1
xsea1=LEM.xsea1;
ysea1=LEM.ysea1;
x=LEM.x_mod;
z=LEM.z_mod;

tsea2=LEM2.sea_rec;%tsea1
xsea2=LEM2.xsea1;
ysea2=LEM2.ysea1;
x2=LEM2.x_mod;
z2=LEM2.z_mod;

%%%%%%%%%%%%%%%%%%% search in time and space %%%%%%%%%%%%%%%%%%%%%%%%
th1=age*1e3;
%shoreline angle
spx=sh(:,1);
spy=sh(:,2);

plote=0;

[counter,mini]=TerraceM_recoccupation(xsea2,ysea2,tsea2,plote);


%ratio=handles.ratio; %search ratio remove double shoreline angles
%cycle=handles.cycle; %glacial cycle duration
[shoreline]=TerraceM_autoshoreline(mini,x2',z2',ratio,cycle);  

[M,I_sh]=min(abs(shoreline(:,3)-th1));
smx=shoreline(I_sh,1)/1000;
smy=shoreline(I_sh,2);



x_disp=(spx/1000)-smx;%offset with model
MOD.x_disp=x_disp;

x_scaled=(sw(:,1)./1000);%scale topography km

%cut porfile
p1x=((spx/1000)-x_disp)+up; %extent of shoot for fit upwards km
p2x=((spx/1000)-x_disp)-down; %extent downwards km

model1(:,1)=(x/1000); %km
model1(:,2)=z;

topo1(:,1)=x_scaled-x_disp;%%%%%%%%%%% error
topo1(:,2)=sw(:,4);
mamo=model1(model1(:,1)<p1x,:);
to=topo1(topo1(:,1)<p1x,:);

%zones for fitting
mod_zone=mamo(mamo(:,1)>p2x,:);
top_zone=to(to(:,1)>p2x,:);

%check again lenght of data and shrink if necesary 
top_zone=top_zone(~isnan(top_zone(:,2)),:);
mod_zone(mod_zone(:,1)>max(top_zone(:,1)),:)=[];

%prepare sh model outputs
%sh_49=[smx, smy];

%mod.sh=sh_49;

% Interpolate & scale to shelf point
mod.xz=mod_zone;

mod.xz(:,1)=mod.xz(:,1)-mod.xz(1,1); %%%%%%%%%%%%% here

nm=numel(mod.xz(:,1));

xvec=[]; 
xvec(:,1)=min(top_zone(:,1)):range(top_zone(:,1))/(nm-1):max(top_zone(:,1));
%xvec=linspace(min(mod_zone(:,1)),max(top_zone(:,1)),nm);


mod.topo_int(:,1)=xvec;
mod.topo_int(:,2)=interp1(top_zone(:,1),top_zone(:,2),xvec,'linear');

%%%%%% RMS

Result=CalcPerf(mod.topo_int,mod.xz);

%extract area between curves
A=mod.topo_int(:,2);A(isnan(A)) = 0;
B=mod.xz(:,2);B(isnan(B)) = 0;
Result.Area=trapz(xvec,abs(A-B));


MOD.mod_zone=mod_zone;
MOD.top_zone=top_zone;
MOD.shoreline=shoreline;
MOD.SH=[(spx/1000)-x_disp,spy];
MOD.x_delta=x_disp;


%plot figure outputs and or save
if mode==1
figure
title(sprintf('Profile %u',prof))
box on
hold on
xlabel('Distance along swath (km)')
ylabel('Elevation (m)')
plot(mod_zone(:,1),mod_zone(:,2),'-k')%model
plot(top_zone(:,1),top_zone(:,2),'r')%reality



%print text
x_text= min(top_zone(:,1))+((max(top_zone(:,1))-min(top_zone(:,1)))/8);
y_text= max(mod_zone(:,2))-((max(top_zone(:,2))-min(top_zone(:,2)))/8);
x_text2= min(top_zone(:,1))+((max(top_zone(:,1))-min(top_zone(:,1)))/7);
y_text2= max(mod_zone(:,2))-((max(top_zone(:,2))-min(top_zone(:,2)))/7);
text(x_text,y_text,sprintf('NRMSE= %.2f',Result.NRMSE));
text(x_text2,y_text2,sprintf('Area= %.0f',Result.Area));

%shoreline plot
t=round(shoreline(:,3),0)/1e3;%isolate time
b = num2str(t); 
c = cellstr(b);%convert to format for labels
dx = (max(x2)-min(x2))/20; % avoid overlap
%
plot(shoreline(:,1)/1e3,shoreline(:,2),'ok','MarkerFaceColor','k');

text((shoreline(:,1)+dx/3)/1e3,shoreline(:,2), c);

%tie shoreline angle model
plot(smx,smy,'sb')%model sh
plot((spx/1000)-x_disp,spy,'sr'); %real sh
ylabel('Elevation (m)')

xlim([min(top_zone(:,1)) max(top_zone(:,1))])
ylim([min(top_zone(:,2)) max(mod_zone(:,2))])

if savepdf==1

rect=[2,8,17,20]; %[xmin ymin width height]
set(gcf,'PaperType','A4');
set(gcf,'PaperUnits','centimeters'); 
set(gcf,'Paperposition',rect);
fout4 = 'FIT';
saveas(gcf,fout4,'pdf')    
    
    
end
end
