function [U]=create_ur2(mtr,dt,varargin)
%create interpolated uplift rate matrix from mtr
%mtr is a two columns matrix the first one containing
%time in ka, and the second the uplift rate (m/ka)
%dt in yrs
%extra arguments:
%'curve' is used to smooth the result
%
%Example
%
%mtr=[0,0.2; ...  
%    100,0.3; ...
%    250,0.5;...
%    500,0.1;
%
%varargin: use 'curve' to make it smooth
%don use extra arguments to make it as straight lines

n=numel(mtr(:,1));

if numel(varargin)>=1

xi=mtr(1,1)*1000:dt:mtr(n,1)*1000;   
    
    
vq = interp1(mtr(:,1)*1000,mtr(:,2),xi,'pchip');

urate=vq;

else
%create uplift rate matrix with a defined time interval for an arbitrary
%slip rate change at user-defined time and magnitude
%inputs are:
%mtr: two clumns matrix containing timeand uplift rate values time, ur  ... tmin tmed tmax // ur_min ur_med ur_max
% mtr=[0 0.5; 370,1.2; 600 1.8];%
% dt: spacing of your matrix in time intervals 
%e.g.: dt=100


minu=(mtr(1,2));%urate
maxu=(mtr(n,2));

tmax= mtr(n,1)*1000;%ka
tmin= mtr(1,1)*1000; 

if n==2
  jmax=((tmax-tmin)/dt)+1;
  X=linspace(minu,maxu,jmax)';
  urate=X;
end

if n==3
medu=mtr(2,2);
tmed=mtr(2,1)*1000;
% model time is counted the opossite time
%direction
jmax=((tmax-tmin)/dt)+1;
jmed=((tmed-tmin)/dt)+1;   
X1=linspace(minu,medu,jmed)';
X2=linspace(medu,maxu,jmax-jmed)';
urate2=vertcat(X1,X2);  
urate=urate2; 
end

if n==4
medu(1)=mtr(2,2);
medu(2)=mtr(3,2);
tmed(1)=mtr(2,1)*1000;
tmed(2)=mtr(3,1)*1000;    
  
jmax=((tmax-tmin)/dt)+1;
jmed(1)=((tmed(1)-tmin)/dt)+1;   %%%%
jmed(2)=((tmed(2)-tmed(1))/dt)+1;  

X1=linspace(minu,medu(1),jmed(1))';
X2=linspace(medu(1),medu(2),jmed(2))';
X3=linspace(medu(2),maxu,jmax-jmed(2)-jmed(1))';
urate2=vertcat(X1,X2,X3);  

urate=urate2; 
end


if n==5
medu(1)=mtr(2,2);
medu(2)=mtr(3,2);
medu(3)=mtr(4,2);

tmed(1)=mtr(2,1)*1000;
tmed(2)=mtr(3,1)*1000;    
tmed(3)=mtr(4,1)*1000;   
  
jmax=((tmax-tmin)/dt)+1;
jmed(1)=((tmed(1)-tmin)/dt)+1;   %%%%
jmed(2)=((tmed(2)-tmed(1))/dt)+1;  
jmed(3)=((tmed(3)-tmed(2))/dt)+1;  


X1=linspace(minu,medu(1),jmed(1))';
X2=linspace(medu(1),medu(2),jmed(2))';
X3=linspace(medu(2),medu(3),jmed(3))';
X4=linspace(medu(3),maxu,jmax-jmed(3)-jmed(2)-jmed(1))';

urate2=vertcat(X1,X2,X3,X4);  

urate=urate2; 
end
end

U.urate=urate;
U.params=mtr;
U.dt=dt;