%% Diffusion modeling function

function [shoreline,points,regr,rms1]=Terracem_diff(swat,thetadegrees,k,t1,ti,t2);

t1=t1*1e3;
t2=t2*1e3;
ti=ti*1e3;

%load swath profile values
x=swat.x; %distance along profile
mi=swat.z_min; %min values%
me=swat.z_mean; %mean values
ma=swat.z_max; %max values
slp=swat.slope; %slope values

% Check if flipped, high part must be at right

%plot swath
 hold on
%plot of topographic curves
hold on
plot(x,ma,'k')
plot(x,me,'color',[0.3 0.3 0.3])
plot(x,mi,'color',[0.6 0.6 0.6])
%hleg1 = legend('Max topography','Mean topography','Min topography','Location','SouthEast');
%xlim([min(x) max(x)]);
box on
grid on
ylabel('Elevation (m)'); 
xlabel('Distance along profile (m)');

disp('Zoom in into the extent of a single cliff for this analysis')

%graphic inputs

        %top point
        disp('enter cliff top, or inflection point of far-field slope at top surface');
        [tops(1,1),tops(1,2)]=ginputc(1,'Color', 'm');


        %base points
        disp('enter top and bottom of paleo abrasion platform');
        [bots(1,1),bots(1,2)]=ginputc(1,'Color', 'b');
        [bots(2,1),bots(2,2)]=ginputc(1,'Color', 'b');
        
        
plot(tops(1,1),tops(1,2),'ok','markerfacecolor','m','MarkerSize',6);
plot(bots(1,1),bots(1,2),'ok','markerfacecolor','b','MarkerSize',6);
plot(bots(2,1),bots(2,2),'ok','markerfacecolor','b','MarkerSize',6); 
       
        
% new part for center point
center=bots(1,2)+((tops(1,2)-bots(1,2))/2);
plot([min(x) max(x)],[center center],'k--')        
        
disp('Mark now the scarp center, should be near the dashed line');
[scarp(1,1),scarp(1,2)]=ginputc(1,'Color', 'y'); 

plot(scarp(1,1),scarp(1,2),'ok','markerfacecolor','y','MarkerSize',8);


% fitting line at base with maximum topo
da(:,1)=x; %x axis now defined as da(:,1)
da(:,2)=ma; %fit respect to maximum topo values
da=sortrows(da,1); 
ny=length(da(:,1)); 
daplat1=da(da(:,1)<bots(1,1),:); %only at base
daplat=daplat1(daplat1(:,1)>bots(2,1),:);

% linear regressions
xp=daplat(:,1); 
yp=daplat(:,2);
[pplat,splat]=polyfit(xp,yp,1);
% extrapolate platform
d=mean(diff(xp));
xx=min(xp):d:max(xp); xx=xx';
[p_plat,d_plat]=polyval(pplat,xx,splat);

%lineal equation solve
nr=numel(p_plat);
x1=xx(1,1); 
x2=xx(nr,1); 
y1=p_plat(1,1); 
y2=p_plat(nr,1);
%y value for center (scarp)
x_scarp=scarp(1,1);
y_scarp=(((x_scarp-x1)*(y2-y1))/(x2-x1))+y1;
%y value for top point
x_tops=tops(1,1);
y_tops=(((x_tops-x1)*(y2-y1))/(x2-x1))+y1;
%y value for min x
x_minx=min(da(:,1));
y_minx=(((x_minx-x1)*(y2-y1))/(x2-x1))+y1;

%table with basal line elements
bline(1,1)=x_scarp;
bline(1,2)=y_scarp;
bline(2,1)=x1;
bline(2,2)=y1;
bline(3,1)=x_minx;
bline(3,2)=y_minx;

%%%%%% slope of far field lines %%%%% (b value comes from here)
ml=(y2-y1)/(x2-x1);

%now the lineal equation again
xt=tops(1,1); yt=tops(1,2);
x_max=max(da(:,1)); %topline at max x value
y_max=(ml*(x_max-xt))+yt;
x_scarp=scarp(1,1);
yt_scarp=(ml*(x_scarp-xt))+yt;

%table with topline elements
tline(1,1)=x_scarp;
tline(1,2)=yt_scarp;
tline(2,1)=xt;
tline(2,2)=yt;
tline(3,1)=x_max;
tline(3,2)=y_max;

%central vertical line that pass trough scarp 
%values of scarp in y at top and baseline 
%points of the line

v_line(1,1)=x_scarp;
v_line(1,2)=yt_scarp;
v_line(2,1)=x_scarp;
v_line(2,2)=y_scarp;

% precentered data plot %%%%%%%%%%%%%%%%%%
%grid off
hold on
plot(bline(:,1),bline(:,2),'r--');
plot(tline(:,1),tline(:,2),'r--');
plot(v_line(:,1),v_line(:,2),'k','LineWidth',1);
text((v_line(1,1)),((v_line(1,2)+scarp(1,2))/2),'a','FontSize',12,'BackgroundColor','white')
text((v_line(1,1)),((v_line(2,2)+scarp(1,2))/2),'a','FontSize',12,'BackgroundColor','white')

%values of a height of scarp/2
a=(yt_scarp-y_scarp)/2;
%value of b far field slope
b=atand(ml);

text(bots(2,1),tops(1,2),['2a = ',(num2str(2*a,'%0.1f')),' m'],'FontSize',12)
text(bots(2,1),((tops(1,2)+scarp(1,2))*0.55),['b = ',(num2str(b,'%0.1f')),' (deg)'],'FontSize',12)


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% CENTERING THE ENTIRE PLOT DATA
%%%%%%%%%% b and a value %%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%defining plot in cartesian plane
offx=x_scarp; %centerpoint x
offy=yt_scarp-a; %centerpoint y

%centering topografic data
nim=numel(da(:,1));
xn(:,1)=x(:,1)-offx;    
dan(:,1)=da(:,1)-offx; %for max topo analysis
dan(:,2)=da(:,2)-offy;

%centering far field slope data
num=numel(tline(:,1)); %numel for bline and tline
tlinen(:,1)=tline(:,1)-offx;
tlinen(:,2)=tline(:,2)-offy;
blinen(:,1)=bline(:,1)-offx;
blinen(:,2)=bline(:,2)-offy;
vlinen(:,1)=v_line(:,1)-offx;
vlinen(:,2)=v_line(:,2)-offy;

%centering bots and tops points of ginputs
topsn(1,1)=tops(1,1)-offx;
topsn(1,2)=tops(1,2)-offy;
botsn(1,1)=bots(2,1)-offx;
botsn(1,2)=bots(2,2)-offy;
scarpn(1,1)=scarp(1,1)-offx;
scarpn(1,2)=scarp(1,2)-offy;

%generating database "parameters"
parameters.offset.uperline=tlinen;
parameters.offset.lowerline=blinen;
parameters.offset.vline=vlinen;
parameters.profile.x=dan(:,1);
parameters.profile.maxtopo=dan;
parameters.profile.slope(:,1)=xn;
parameters.profile.slope(:,2)=slp;
parameters.inputs.a=a;
parameters.inputs.b=b;
parameters.profile.nim=nim; %nim=number of elements for dx calculation
%add ginputs point to paramaters to constrain the extension of rms analysis
parameters.inputs.topsn=topsn;
parameters.inputs.botsn=botsn;
parameters.inputs.scarp=scarpn;
%%%%%%%%%%%% Difussion %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%cut plot area using botsn and topsn%%%%%%%%%%%%%%%%%%%%%%%%

parameters.cut.maxtopo=parameters.profile.maxtopo; %vectorial form: first create a matrix equal that the one that i want to modify
parameters.cut.maxtopo(parameters.cut.maxtopo(:,1)>(parameters.inputs.topsn(1,1)+15),:)=[]; %vectorial form, excluve values bigger than x in topsn
parameters.cut.maxtopo(parameters.cut.maxtopo(:,1)<(parameters.inputs.botsn(1,1)-0),:)=[]; %vectorial form, excluve values bigger than x in botsn
nm=numel(parameters.cut.maxtopo(:,1));
parameters.cut.nim=nm;

clear x
%generate a sintetic distribution of the same size of the input topography
xmin=(parameters.cut.maxtopo(1,1));
dx=((parameters.cut.maxtopo(parameters.cut.nim,1)-parameters.cut.maxtopo(1,1))/(parameters.cut.nim-1));
xmax=(parameters.cut.maxtopo(parameters.cut.nim,1));
x=(xmin:dx:xmax);

a=parameters.inputs.a; %half oh the scarp elevation obtained from manual picking at the begining
bdegrees=parameters.inputs.b; %far field slope value, obtained from manual picking at the begining

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%% LOOPING DIFUSSION %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%% loop range parameters %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%% change k (difusion coeficient) and  time %%%%%%%%%%%%%%%%%%

t=t1:ti:t2; %fix this piece of shit
ktrange=t.*k;
rms=zeros(numel(ktrange),1); %matris de zeros igual a ktrange
topopred=(parameters.cut.maxtopo(:,2))';

% RUN MODELS
j=1;
for kt=ktrange
 
model=finitescarp(thetadegrees,a,x,kt,bdegrees);
%%% RMS
rms(j)=sqrt(sum((topopred(:)-(-model(:))).^2)/numel(topopred));

%fprintf('...model %u of %u ready...\n',j,numel(ktrange));
j=j+1;

end


rr=horzcat(ktrange',rms);
ir=sortrows(rr,2);
parameters.KT_RMS=ir;
best=parameters.KT_RMS(1,:);

%%%%%%%%%%% Shoreline angle extraction and error %%%%%%%%%%%%%%%%%%%%

fface=[thetadegrees 3]; %angular rangle, mean=60 error =5
da2=parameters.cut.maxtopo;
daxclif=da2(da2(:,1)>=0,:); %change scarp por la inversa del shoreline angle para calcular variacion angular
xc=-daxclif(:,1); %%%%%%%%%%%%
yc=(-tand(fface(1,1)).*abs(daxclif(:,1)-daxclif(1,1)))+daxclif(1,2);
yc1=daxclif(1,2)-((daxclif(:,1)-daxclif(1,1))./tand(90-fface(1,1)+fface(1,2)));
yc2=daxclif(1,2)-((daxclif(:,1)-daxclif(1,1))./tand(90-fface(1,1)-fface(1,2)));    
[pclif,sclif]=polyfit(xc,yc,1);
[pclif1,sclif1]=polyfit(xc,yc1,1);
[pclif2,sclif2]=polyfit(xc,yc2,1);
xg=daplat(:,1)-offx; %valores alcanzados por la interpolacion
yg=daplat(:,2)-offy;
[pplat,ssplat]=polyfit(xg,yg,1);
% extrapolate
dxm=mean(diff(xg));
xxx=min(xg):dxm:max(xc); 
xxx=xxx';
[pp_plat,dd_plat]=polyval(pplat,xxx,ssplat);
[p_clif,d_clif]=polyval(pclif,xxx,sclif);
% intersect
mc=pclif(1,1); 
ic=pclif(1,2); 
mp=pplat(1,1); 
ip=pplat(1,2);
sh=[(-ic+ip)/(mc-mp),(ip*mc-ic*mp)/(mc-mp)];
eshx=sh(1,1); 
eshz=sh(1,2);
[shzp,shzep]=polyval(pplat,eshx,ssplat);

% propagate 2s error by intersecting 2s regressions
% intersect max
mc=pclif1(1,1); 
ic=pclif1(1,2);
sh1=[(-ic+ip)/(mc-mp),(ip*mc-ic*mp)/(mc-mp)];
shx1=sh1(1,1); 
shz1=sh1(1,2);
[shzc1,shzec1]=polyval(pplat,shx1,splat);

% intersect min
mc=pclif2(1,1); 
ic=pclif2(1,2);
sh2=[(-ic+ip)/(mc-mp),(ip*mc-ic*mp)/(mc-mp)];
shx2=sh2(1,1); 
shz2=sh2(1,2);
[shzc2,shzec2]=polyval(pplat,shx2,splat);

% calculate error
shze1=shz1-shzec1;
shze2=shz2+shzec2;
shze=(shze2-shze1);

% transform xc and yc to original coordinates
xcyc(:,1)=xc; xcyc(:,2)=yc;
xcyc=xcyc(xcyc(:,2)>eshz,:);
xcyc1(:,1)=xc; xcyc1(:,2)=yc1;
xcyc1=xcyc1(xcyc1(:,2)>eshz,:);
xcyc2(:,1)=xc; xcyc2(:,2)=yc2;
xcyc2=xcyc2(xcyc2(:,2)>eshz,:);

%outputs
shoreline_angle_x=eshx+offx; %distance along profile
shoreline_angle_y=eshz+offy; %elevation
error_shoreline=2*shze; %error in elevation


%%%%%%% plots

hold on
errorbar(shoreline_angle_x,shoreline_angle_y,shze,'ok','markerfacecolor','k')
%scarp geometry
hinitial=finitescarp(thetadegrees,a, x, 0.0001,bdegrees);%k=0.0001
bestfit=finitescarp(thetadegrees,a,x,best(1,1),bdegrees);
%%%%%%%%%%%%%%%%%% plot best model
plot(x+offx,-hinitial+offy,'b-')
plot(parameters.cut.maxtopo(:,1)+offx,parameters.cut.maxtopo(:,2)+offy,'k')
plot(x+offx,-bestfit+offy,'r-','LineWidth',1.5)

sh_fin=[shoreline_angle_x,shoreline_angle_y];

%get coordinates in map view, point2utm do this
point2utm=Terracem_point2utm(swat,sh_fin);
Rx=point2utm(:,1); %UTM E
Ry=point2utm(:,2); %UTM N

shoreline=[Rx Ry shoreline_angle_x shoreline_angle_y shze]; %number of shoreline,E, N, distance along profile,z ze
points.plat=([xp,yp]);
points.bot=bots;
points.top=tops;
points.center=scarp;

regr.plat=[xxx+offx , pp_plat+offy, pp_plat+2*dd_plat+offy , pp_plat-2*dd_plat+offy];
%regr.clif=[xcyc(:,1)+offx , xcyc(:,2)+offy , xcyc1(:,2)+offy , xcyc2(:,2)+offy];


rms1.ktrange=ktrange';
rms1.rms=rms;
rms1.bestkt=best(1,1);
rms1.bestrms=best(1,2);

