function [shoreline,points,regr]=TerraceM_staircase(swat)

format long
%load swath profile values
x=swat.x; %distance along profile
mi=swat.z_min; %min values%
me=swat.z_mean; %mean values
ma=swat.z_max; %max values
slp=swat.slope; %slope values
type=swat.type_profile;

hold on
plot(x,ma,'k')
plot(x,me,'color',[0.3 0.3 0.3])
plot(x,mi,'color',[0.6 0.6 0.6])
%hleg1 = legend('Max topography','Mean topography','Min topography','Location','SouthEast');
%xlim([min(x) max(x)]);
grid on 
box on
yl1=ylabel('Elevation (m)'); 
xl1=xlabel('Distance along profile (m)');

%Graphic inputs
disp('enter top and bottom of paleocliff extrapolation line');
%two user defined points for cliff
[clif(1,1),clif(1,2)]=ginputc(1,'Color', 'r'); 
[clif(2,1),clif(2,2)]=ginputc(1,'Color', 'r');

disp('enter top and bottom of paleo abrasion platform');
%two user defined points for platform
[plat(1,1),plat(1,2)]=ginputc(1,'Color', 'b'); 
[plat(2,1),plat(2,2)]=ginputc(1,'Color', 'b');  

da(:,1)=x; 
da(:,2)=ma; 
md=swat; 
ny=length(md(:,1)); 

%area for interpolation
daclif1=da(da(:,1)>clif(2,1),:);
daclif=daclif1(daclif1(:,1)<clif(1,1),:);
daplat1=da(da(:,1)>plat(2,1),:); 
daplat=daplat1(daplat1(:,1)<plat(1,1),:);

% fit cliff
xc=daclif(:,1); yc=daclif(:,2);
[pclif,sclif]=polyfit(xc,yc,1);
% fit plat
xp=daplat(:,1); yp=daplat(:,2);
[pplat,splat]=polyfit(xp,yp,1);

% save points and project profile
clifx=[clif(1,1),clif(1,2),clif(2,1),clif(2,2)];
platx=[plat(1,1),plat(1,2),plat(2,1),plat(2,2)];

d=xc(2)-xc(1);
d=abs(d);
xx=min(xp):d:max(xc); xx=xx';

%regressions
[p_clif,d_clif]=polyval(pclif,xx,sclif);
[p_plat,d_plat]=polyval(pplat,xx,splat);

% plot intersection
cla
hold on
plot(x,ma,'-b'), grid on, box on %ma
plot(x,mi,'-k'), grid on, box on %ma
plot(xc,yc,'ok','MarkerSize',5,'MarkerFaceColor','w')
plot(xx,p_clif,'r-',...
   xx,p_clif+2*d_clif,'r--',xx,p_clif-2*d_clif,'r--') %, axis equal tight
hold on
plot(xp,yp,'ok','MarkerSize',5,'MarkerFaceColor','w')
plot(xx,p_plat,'r-',...
   xx,p_plat+2*d_plat,'r--',xx,p_plat-2*d_plat,'r--') 
axis([min(xx)-15 max(xx)+15 min(yp)-15 max(yc)+15]); 
%hleg=legend('Max topography','Min topography','Platform and cliff points','linear fit','2s','shoreline angle','location','northwest');
yl1=ylabel('Elevation (m)'); 
xl1=xlabel('Distance along swath(m)');

% find intersections
mc=pclif(1,1); mp=pplat(1,1); ic=pclif(1,2); ip=pplat(1,2);
% output shoreline angle is sh
sh=[(-ic+ip)/(mc-mp),(ip*mc-ic*mp)/(mc-mp)];
shx=sh(1,1); %distance along ptofile
shz=sh(1,2); %elevation
%intersect to determine error in Z
V1=[xx,p_plat+2*d_plat];
V2=[xx,p_clif-2*d_clif];
[X0,Y0]=intersections(V1(:,1),V1(:,2),V2(:,1),V2(:,2));
shze=(Y0-shz)*1;


%text on plot
xL = get(gca,'XLim'); yL = get(gca,'YLim');
dxL=xL(2)-xL(1); dyL=yL(2)-yL(1);
text(shx-dxL/10,shz+dyL/10,sprintf('%.2f $\\pm$ %.2f m',shz,shze),'FontSize',12,'BackgroundColor',[1 1 1],'interpreter','latex'); %Shoreline angle value and location

%get coordinates in map view, point2utm do this
point2utm=Terracem_point2utm(swat,sh);

Rx=point2utm(:,1); %UTM E
Ry=point2utm(:,2); %UTM N

%plot shoreline angle with error in z
h=errorbar(shx,shz,shze,'ok','MarkerFaceColor','k'); 
%errorbar_tick(h, 30);
box on
ylabel('Elevation (m)'); xlabel('Distance along swath (m)');

%arrange outputs
shoreline=[Rx Ry shx shz shze]; %number of shoreline,E, N, distance along profile,z ze
if nargout > 1
%points=vertcat(platx',clifx');
points=vertcat([xc,yc],[xp,yp]);
%regressions
regr.cliff=[xx,p_clif,p_clif+2*d_clif,p_clif-2*d_clif];
regr.plat=[xx,p_plat,p_plat+2*d_plat,p_plat-2*d_plat];
end